Name: 		google-authenticator
Version:        1.10
Release:        1
Summary:	One-time pass-code support using open standards

License:        Apache License 2
URL:            https://github.com/google/%{name}-libpam/
Source0:        https://github.com/google/%{name}-libpam/archive/refs/tags/%{name}-libpam-%{version}.tar.gz

Patch0:		%{name}-libpam-auth-1.10-getopt_asprintf.patch
Patch1:		%{name}-libpam-auth-1.10-vsyslog_const.patch
Patch2:		%{name}-libpam-base32-1.10-getopt_err.patch
Patch3:		%{name}-libpam-test-1.10.patch

BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  make
%if %{toolchain} == "gcc"
Requires:       libgcc >= 10.3.0
%endif

%description
The Google Authenticator package contains a plug-able authentication
module (PAM) which allows login using one-time pass-codes conforming to
the open standards developed by the Initiative for Open Authentication
(OATH) (which is unrelated to OAuth).

Pass-code generators are available (separately) for several mobile
platforms.

These implementations support the HMAC-Based One-time Password (HOTP)
algorithm specified in RFC 4226 and the Time-based One-time Password
(TOTP) algorithm currently in draft.

%prep
export PATH=/opt/freeware/bin:$PATH

%setup -q -n %{name}-libpam-%{version}
%patch0
%patch1
%patch2
%patch3

%build

# Build only 32-bit as of now as ssh is 32-bit for AIX.
export CC="%{__cc__} -O2"
export CXX="%{__cxx__} -O2"

./bootstrap.sh
./configure  --prefix=/opt/freeware --enable-shared
gmake V=1

%install
gmake install DESTDIR=${RPM_BUILD_ROOT}
mkdir -p %{buildroot}/usr/lib/security
install -p .libs/pam_google_authenticator.so %{buildroot}%{_prefix}/lib/security/
cd %{buildroot}/usr/lib/security
ln -sf ../../..%{_libdir}/security/pam_google_authenticator.so pam_google_authenticator.so

# For one of the testcase tests/pam_google_authenticator_unittest
# pam_google_authenticator depends on the symbols provided by pam_google_authenticator_unittest
# instead of symbols from libpam.a.
# To run testcase we might need to rebuild with brtl flag.

# gdb output without brtl
# Breakpoint 2.2, 0xd1862010 in pam_get_user () from /usr/lib/libpam.a(shr.o)
# (gdb) bt
# #0  0xd1862010 in pam_get_user () from /usr/lib/libpam.a(shr.o)

# gdb output with brtl
# Breakpoint 2.1, pam_get_user (pamh=0x0, user=0x2ff20fe8, prompt=0x0) at tests/pam_google_authenticator_unittest.c:72
# 72        return pam_get_item(pamh, PAM_USER, (void *)user);
# (gdb) bt
# #0  pam_get_user (pamh=0x0, user=0x2ff20fe8, prompt=0x0) at tests/pam_google_authenticator_unittest.c:72

%check
gmake distclean
export CC="%{__cc__} -O2"
export CXX="%{__cxx__} -O2"
export LDFLAGS="-Wl,-brtl"

./configure  --prefix=/opt/freeware --enable-shared
gmake -k check V=1 || true

%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(-,root,system)
%doc LICENSE README.md FILEFORMAT
%{_libdir}/security/pam_google_authenticator.so
/usr/lib/security/pam_google_authenticator.so
%{_bindir}/%{name}
%{_datadir}/man/man1/*
%{_datadir}/man/man8/*

%changelog
* Sat Sep 07 2024 Sangamesh Mallayya<smallayy@in.ibm.com> - 1.10-1
- First port for AIX Toolbox.
